@@ -1130,6 +1130,11 @@ arv_camera_get_frame_rate_bounds (ArvCamera *camera, double *min, double *max, G
 					return;
 				}
 
+				if (max != NULL)
+					*max = 0;
+				if (min != NULL)
+					*min = 0;
+
 				for (i = 0; i < n_values; i++) {
 					if (values[i] > 0) {
 						double s;
@@ -2546,7 +2551,9 @@ arv_camera_gv_set_stream_options (ArvCamera *camera, ArvGvStreamOption options)
 gboolean
 arv_camera_is_uv_device	(ArvCamera *camera)
 {
+#if ARAVIS_HAS_USB
 	ArvCameraPrivate *priv = arv_camera_get_instance_private (camera);
+#endif
 
 	g_return_val_if_fail (ARV_IS_CAMERA (camera), FALSE);
 
@@ -2845,7 +2852,7 @@ ArvCamera *
 arv_camera_new (const char *name, GError **error)
 {
 	/* if you need to apply or test for fixups based on the camera model
-	   please do so in arv_camera_constructor and not here, as this breaks
+	   please do so in arv_camera_constructed and not here, as this breaks
 	   objects created with g_object_new, which includes but is not limited to
 	   introspection users */
 
@@ -2892,7 +2899,7 @@ arv_camera_constructed (GObject *object)
 						     "Device '%s' not found", priv->name);
 			else
 				error = g_error_new (ARV_DEVICE_ERROR, ARV_DEVICE_ERROR_NOT_FOUND,
-						     "No supported deice found");
+						     "No supported device found");
 		}
 
 		g_clear_error (&priv->init_error);
@@ -3049,4 +3056,3 @@ arv_camera_initable_iface_init (GInitableIface *iface)
 {
 	iface->init = arv_camera_initable_init;
 }
-
