@@ -541,6 +541,106 @@ arv_fake_camera_diagonal_ramp (ArvBuffer *buffer, void *fill_pattern_data,
 				}
 			break;
 
+        case ARV_PIXEL_FORMAT_BAYER_BG_8:
+            for (y = 0; y < height; y++)
+                for (x = 0; x < width; x++) {
+                    unsigned int index;
+					pixel_value = (x + buffer->priv->frame_id + y) % 255;
+					pixel_value *= scale;
+					index = CLAMP (pixel_value, 0, 255);
+
+                    // BG
+                    // GR
+                    unsigned char *pixel = &buffer->priv->data [y * width + x];
+                    if (x & 1) {
+                        if (y & 1)
+                            *pixel = jet_colormap [index].b;
+                        else
+                            *pixel = jet_colormap [index].g;
+                    } else {
+                        if (y & 1)
+                            *pixel = jet_colormap [index].g;
+                        else
+                            *pixel = jet_colormap [index].r;
+                    }
+                }
+            break;
+
+        case ARV_PIXEL_FORMAT_BAYER_GB_8:
+            for (y = 0; y < height; y++)
+                for (x = 0; x < width; x++) {
+                    unsigned int index;
+					pixel_value = (x + buffer->priv->frame_id + y) % 255;
+					pixel_value *= scale;
+					index = CLAMP (pixel_value, 0, 255);
+
+                    // GB
+                    // RG
+                    unsigned char *pixel = &buffer->priv->data [y * width + x];
+                    if (x & 1) {
+                        if (y & 1)
+                            *pixel = jet_colormap [index].g;
+                        else
+                            *pixel = jet_colormap [index].b;
+                    } else {
+                        if (y & 1)
+                            *pixel = jet_colormap [index].r;
+                        else
+                            *pixel = jet_colormap [index].g;
+                    }
+                }
+            break;
+
+        case ARV_PIXEL_FORMAT_BAYER_GR_8:
+            for (y = 0; y < height; y++)
+                for (x = 0; x < width; x++) {
+					unsigned int index;
+					pixel_value = (x + buffer->priv->frame_id + y) % 255;
+					pixel_value *= scale;
+					index = CLAMP (pixel_value, 0, 255);
+
+                    // GR
+                    // BG
+                    unsigned char *pixel = &buffer->priv->data [y * width + x];
+                    if (x & 1) {
+                        if (y & 1)
+                            *pixel = jet_colormap [index].g;
+                        else
+                            *pixel = jet_colormap [index].r;
+                    } else {
+                        if (y & 1)
+                            *pixel = jet_colormap [index].b;
+                        else
+                            *pixel = jet_colormap [index].g;
+                    }
+                }
+            break;
+
+        case ARV_PIXEL_FORMAT_BAYER_RG_8:
+            for (y = 0; y < height; y++)
+                for (x = 0; x < width; x++) {
+					unsigned int index;
+					pixel_value = (x + buffer->priv->frame_id + y) % 255;
+					pixel_value *= scale;
+					index = CLAMP (pixel_value, 0, 255);
+
+                    // RG
+                    // GB
+                    unsigned char *pixel = &buffer->priv->data [y * width + x];
+                    if (x & 1) {
+                        if (y & 1)
+                            *pixel = jet_colormap [index].r;
+                        else
+                            *pixel = jet_colormap [index].g;
+                    } else {
+                        if (y & 1)
+                            *pixel = jet_colormap [index].g;
+                        else
+                            *pixel = jet_colormap [index].b;
+                    }
+                }
+            break;
+
 		case ARV_PIXEL_FORMAT_RGB_8_PACKED:
 			for (y = 0; y < height; y++)
 				for (x = 0; x < width; x++) {
