@@ -70,6 +70,14 @@ typedef enum {
 	ARV_GC_IS_LINEAR_YES
 } ArvGcIsLinear;
 
+typedef enum {
+	ARV_GC_VISIBILITY_UNDEFINED = -1,
+	ARV_GC_VISIBILITY_INVISIBLE,
+	ARV_GC_VISIBILITY_GURU,
+	ARV_GC_VISIBILITY_EXPERT,
+	ARV_GC_VISIBILITY_BEGINNER
+} ArvGcVisibility;
+
 G_END_DECLS
 
 #endif
