@@ -48,6 +48,7 @@ typedef struct {
 
 	ArvGcPropertyNode *tooltip;
 	ArvGcPropertyNode *description;
+	ArvGcPropertyNode *visibility;
 	ArvGcPropertyNode *display_name;
 	ArvGcPropertyNode *is_implemented;
 	ArvGcPropertyNode *is_available;
@@ -85,6 +86,9 @@ arv_gc_feature_node_post_new_child (ArvDomNode *self, ArvDomNode *child)
 			case ARV_GC_PROPERTY_NODE_TYPE_DESCRIPTION:
 				priv->description = property_node;
 				break;
+			case ARV_GC_PROPERTY_NODE_TYPE_VISIBILITY:
+				priv->visibility = property_node;
+				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_DISPLAY_NAME:
 				priv->display_name = property_node;
 				break;
@@ -124,6 +128,9 @@ arv_gc_feature_node_pre_remove_child (ArvDomNode *self, ArvDomNode *child)
 			case ARV_GC_PROPERTY_NODE_TYPE_DESCRIPTION:
 				priv->description = NULL;
 				break;
+			case ARV_GC_PROPERTY_NODE_TYPE_VISIBILITY:
+				priv->visibility = NULL;
+				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_DISPLAY_NAME:
 				priv->description = NULL;
 				break;
@@ -207,72 +214,52 @@ arv_gc_feature_node_get_name (ArvGcFeatureNode *node)
 }
 
 const char *
-arv_gc_feature_node_get_tooltip (ArvGcFeatureNode *node, GError **error)
+arv_gc_feature_node_get_tooltip (ArvGcFeatureNode *node)
 {
 	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (node);
-	const char *tooltip;
-	GError *local_error = NULL;
 
 	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (node), NULL);
-	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
 	if (priv->tooltip == NULL)
 		return NULL;
 
-	tooltip = arv_gc_property_node_get_string (priv->tooltip, &local_error);
-
-	if (local_error != NULL) {
-		g_propagate_error (error, local_error);
-		return NULL;
-	}
-
-	return tooltip;
+	return arv_gc_property_node_get_string (priv->tooltip, NULL);
 }
 
 const char *
-arv_gc_feature_node_get_description (ArvGcFeatureNode *node, GError **error)
+arv_gc_feature_node_get_description (ArvGcFeatureNode *node)
 {
 	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (node);
-	const char *description;
-	GError *local_error = NULL;
 
 	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (node), NULL);
-	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
 	if (priv->description == NULL)
 	       return NULL;
 
-	description = arv_gc_property_node_get_string (priv->description, &local_error);
+	return arv_gc_property_node_get_string (priv->description, NULL);
+}
 
-	if (local_error != NULL) {
-		g_propagate_error (error, local_error);
-		return NULL;
-	}
+ArvGcVisibility
+arv_gc_feature_node_get_visibility (ArvGcFeatureNode *node)
+{
+	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (node);
 
-	return description;
+	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (node), ARV_GC_VISIBILITY_UNDEFINED);
+
+	return arv_gc_property_node_get_visibility (priv->visibility, ARV_GC_VISIBILITY_BEGINNER);
 }
 
 const char *
-arv_gc_feature_node_get_display_name (ArvGcFeatureNode *node, GError **error)
+arv_gc_feature_node_get_display_name (ArvGcFeatureNode *node)
 {
 	ArvGcFeatureNodePrivate *priv = arv_gc_feature_node_get_instance_private (node);
-	const char *display_name;
-	GError *local_error = NULL;
 
 	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (node), NULL);
-	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
 	if (priv->display_name == NULL)
 	       return NULL;
 
-	display_name = arv_gc_property_node_get_string (priv->display_name, &local_error);
-
-	if (local_error != NULL) {
-		g_propagate_error (error, local_error);
-		return NULL;
-	}
-
-	return display_name;
+	return arv_gc_property_node_get_string (priv->display_name, NULL);
 }
 
 gboolean
@@ -372,7 +359,9 @@ arv_gc_feature_node_set_value_from_string (ArvGcFeatureNode *self, const char *s
 	g_return_if_fail (ARV_IS_GC_FEATURE_NODE (self));
 	g_return_if_fail (string != NULL);
 
-	if (ARV_IS_GC_INTEGER (self)) {
+	if (ARV_IS_GC_ENUMERATION (self)) {
+		arv_gc_enumeration_set_string_value (ARV_GC_ENUMERATION (self), string, error);
+	} else if (ARV_IS_GC_INTEGER (self)) {
 		arv_gc_integer_set_value (ARV_GC_INTEGER (self), g_ascii_strtoll (string, NULL, 0), error);
 	} else if (ARV_IS_GC_FLOAT (self)) {
 		arv_gc_float_set_value (ARV_GC_FLOAT (self), g_ascii_strtod (string, NULL), error);
@@ -380,8 +369,6 @@ arv_gc_feature_node_set_value_from_string (ArvGcFeatureNode *self, const char *s
 		arv_gc_string_set_value (ARV_GC_STRING (self), string, error);
 	} else if (ARV_IS_GC_BOOLEAN (self)) {
 		arv_gc_boolean_set_value (ARV_GC_BOOLEAN (self), g_strcmp0 (string, "true") == 0 ? 1 : 0, error);
-	} else if (ARV_IS_GC_ENUMERATION (self)) {
-		arv_gc_enumeration_set_string_value (ARV_GC_ENUMERATION (self), string, error);
 	} else {
 		g_set_error (error, ARV_GC_ERROR, ARV_GC_ERROR_SET_FROM_STRING_UNDEFINED,
 			     "Don't know how to set %s value from string", arv_dom_node_get_node_name (ARV_DOM_NODE (self)));
@@ -407,7 +394,9 @@ arv_gc_feature_node_get_value_as_string (ArvGcFeatureNode *self, GError **error)
 
 	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (self), NULL);
 
-	if (ARV_IS_GC_INTEGER (self)) {
+	if (ARV_IS_GC_ENUMERATION (self)) {
+		return arv_gc_enumeration_get_string_value (ARV_GC_ENUMERATION (self), error);
+	} else if (ARV_IS_GC_INTEGER (self)) {
 		g_free (priv->string_buffer);
 		priv->string_buffer = g_strdup_printf ("%" G_GINT64_FORMAT, arv_gc_integer_get_value (ARV_GC_INTEGER (self), error));
 		return priv->string_buffer;
@@ -419,8 +408,6 @@ arv_gc_feature_node_get_value_as_string (ArvGcFeatureNode *self, GError **error)
 		return arv_gc_string_get_value (ARV_GC_STRING (self), error);
 	} else if (ARV_IS_GC_BOOLEAN (self)) {
 		return arv_gc_boolean_get_value (ARV_GC_BOOLEAN (self), error) ? "true" : "false";
-	} else if (ARV_IS_GC_ENUMERATION (self)) {
-		return arv_gc_enumeration_get_string_value (ARV_GC_ENUMERATION (self), error);
 	}
 
 	g_set_error (error, ARV_GC_ERROR, ARV_GC_ERROR_SET_FROM_STRING_UNDEFINED,
