@@ -59,7 +59,7 @@
 #define ARV_GV_STREAM_POLL_TIMEOUT_US			1000000
 #define ARV_GV_STREAM_PACKET_TIMEOUT_US_DEFAULT		40000
 #define ARV_GV_STREAM_FRAME_RETENTION_US_DEFAULT	200000
-#define ARV_GV_STREAM_PACKET_REQUEST_RATIO_DEFAULT	0.10
+#define ARV_GV_STREAM_PACKET_REQUEST_RATIO_DEFAULT	0.25
 
 #define ARV_GV_STREAM_DISCARD_LATE_FRAME_THRESHOLD	100
 
@@ -109,12 +109,14 @@ typedef struct {
 
 	guint n_packets;
 	ArvGvStreamPacketData *packet_data;
+
+	guint n_packet_resend_requests;
+	gboolean resend_ratio_reached;
 } ArvGvStreamFrameData;
 
 struct _ArvGvStreamThreadData {
 	GCancellable *cancellable;
 
-	ArvGvDevice *gv_device;
 	ArvStream *stream;
 
 	ArvStreamCallback callback;
@@ -161,6 +163,7 @@ struct _ArvGvStreamThreadData {
 	guint n_ignored_packets;
 	guint n_resend_requests;
 	guint n_resent_packets;
+	guint n_resend_ratio_reached;
 	guint n_duplicated_packets;
 
 	ArvStatistic *statistic;
@@ -426,11 +429,11 @@ _missing_packet_check (ArvGvStreamThreadData *thread_data,
 		       guint32 packet_id,
 		       guint64 time_us)
 {
-	guint n_packet_requests = 0;
 	int i;
 
 	if (thread_data->packet_resend == ARV_GV_STREAM_PACKET_RESEND_NEVER ||
-	    frame->error_packet_received)
+	    frame->error_packet_received ||
+	    frame->resend_ratio_reached)
 		return;
 
 	if ((int) (frame->n_packets * thread_data->packet_request_ratio) <= 0)
@@ -449,15 +452,18 @@ _missing_packet_check (ArvGvStreamThreadData *thread_data,
 				if (first_missing >= 0) {
 					int j;
 
-					if (i - first_missing + n_packet_requests >
+					if (i - first_missing + frame->n_packet_resend_requests >
 					    (frame->n_packets * thread_data->packet_request_ratio)) {
-						n_packet_requests += i - first_missing;
+						frame->n_packet_resend_requests += i - first_missing;
 
-						arv_log_stream_thread ("[GvStream::missing_packet_check]"
+						arv_debug_stream_thread ("[GvStream::missing_packet_check]"
 									 " Maximum number of packet requests "
 									 "reached at dt = %" G_GINT64_FORMAT ", n_requests = %u/%u",
 									 time_us - frame->first_packet_time_us,
-									 n_packet_requests, frame->n_packets);
+									 frame->n_packet_resend_requests, frame->n_packets);
+
+						thread_data->n_resend_ratio_reached++;
+						frame->resend_ratio_reached = TRUE;
 
 						return;
 					}
@@ -480,15 +486,18 @@ _missing_packet_check (ArvGvStreamThreadData *thread_data,
 		if (first_missing >= 0) {
 			int j;
 
-			if (i - first_missing + n_packet_requests >
+			if (i - first_missing + frame->n_packet_resend_requests >
 			    (frame->n_packets * thread_data->packet_request_ratio)) {
-				n_packet_requests += i - first_missing;
+				frame->n_packet_resend_requests += i - first_missing;
 
-				arv_log_stream_thread ("[GvStream::missing_packet_check]"
+				arv_debug_stream_thread ("[GvStream::missing_packet_check]"
 						       " Maximum number of packet requests "
 						       "reached at dt = %" G_GINT64_FORMAT ", n_requests = %u/%u",
 						       time_us - frame->first_packet_time_us,
-						       n_packet_requests, frame->n_packets);
+						       frame->n_packet_resend_requests, frame->n_packets);
+
+				thread_data->n_resend_ratio_reached++;
+				frame->resend_ratio_reached = TRUE;
 
 				return;
 			}
@@ -1086,7 +1095,7 @@ arv_gv_stream_constructed (GObject *object)
 	ArvGvStreamPrivate *priv = arv_gv_stream_get_instance_private (ARV_GV_STREAM (stream));
 	ArvGvStreamThreadData *thread_data;
 	ArvGvStreamOption options;
-	ArvGvDevice *gv_device = NULL;
+	g_autoptr (ArvGvDevice) gv_device = NULL;
 	GInetAddress *interface_address;
 	GInetAddress *device_address;
 	guint64 timestamp_tick_frequency;
@@ -1115,10 +1124,9 @@ arv_gv_stream_constructed (GObject *object)
 		return;
 	}
 
-	thread_data = g_new (ArvGvStreamThreadData, 1);
+	thread_data = g_new0 (ArvGvStreamThreadData, 1);
 
 	thread_data->stream = stream;
-	thread_data->gv_device = gv_device;
 
 	g_object_get (object,
 		      "callback", &thread_data->callback,
@@ -1134,33 +1142,12 @@ arv_gv_stream_constructed (GObject *object)
 	thread_data->use_packet_socket = (options & ARV_GV_STREAM_OPTION_PACKET_SOCKET_DISABLED) == 0;
 
 	thread_data->packet_id = 65300;
-	thread_data->last_frame_id = 0;
-
-	thread_data->n_completed_buffers = 0;
-	thread_data->n_failures = 0;
-	thread_data->n_underruns = 0;
-	thread_data->n_aborteds = 0;
-	thread_data->n_timeouts = 0;
-	thread_data->n_missing_frames = 0;
-
-	thread_data->n_size_mismatch_errors = 0;
-
-	thread_data->n_received_packets = 0;
-	thread_data->n_missing_packets = 0;
-	thread_data->n_error_packets = 0;
-	thread_data->n_ignored_packets = 0;
-	thread_data->n_resent_packets = 0;
-	thread_data->n_resend_requests = 0;
-	thread_data->n_duplicated_packets = 0;
 
 	thread_data->statistic = arv_statistic_new (1, 5000, 200, 0);
-	thread_data->statistic_count = 0;
 
 	arv_statistic_set_name (thread_data->statistic, 0, "Buffer reception time");
 
 	thread_data->socket_buffer_option = ARV_GV_STREAM_SOCKET_BUFFER_FIXED;
-	thread_data->socket_buffer_size = 0;
-	thread_data->current_socket_buffer_size = 0;
 
 	priv->thread_data = thread_data;
 
@@ -1355,6 +1342,8 @@ arv_gv_stream_finalize (GObject *object)
 				  thread_data->n_resend_requests);
 		arv_debug_stream ("[GvStream::finalize] n_resent_packets       = %u",
 				  thread_data->n_resent_packets);
+		arv_debug_stream ("[GvStream::finalize] n_resend_ratio_reached = %u",
+				  thread_data->n_resend_ratio_reached);
 		arv_debug_stream ("[GvStream::finalize] n_duplicated_packets   = %u",
 				  thread_data->n_duplicated_packets);
 
