@@ -55,8 +55,8 @@ G_BEGIN_DECLS
 #define ARV_ABRM_TIMESTAMP_LATCH		0x01f8
 #define ARV_ABRM_TIMESTAMP_INCREMENT		0x01fc
 #define ARV_ABRM_ACCESS_PRIVILEGE		0x0204
-#define ARV_ABRM_PROTOCOL_ENDIANESS		0x0208
-#define ARV_ABRM_IMPLEMENTATION_ENDIANESS	0x020c
+#define ARV_ABRM_PROTOCOL_ENDIANNESS		0x0208
+#define ARV_ABRM_IMPLEMENTATION_ENDIANNESS	0x020c
 #define ARV_ABRM_RESERVED			0x0210
 
 #define ARV_SBRM_U3V_VERSION			0x0000
