@@ -212,7 +212,7 @@ arv_uv_stream_thread (void *data)
 					}
 					break;
 				default:
-					arv_debug_stream_thread ("Unkown packet type");
+					arv_debug_stream_thread ("Unknown packet type");
 					break;
 			}
 		}
@@ -459,6 +459,7 @@ arv_uv_stream_finalize (GObject *object)
 		arv_debug_stream ("[UvStream::finalize] n_underruns            = %u",
 				  thread_data->n_underruns);
 
+		g_clear_object (&thread_data->uv_device);
 		g_clear_pointer (&priv->thread_data, g_free);
 	}
 
