@@ -34,28 +34,34 @@
 #include <arvdebug.h>
 #include <arvmisc.h>
 
-struct _ArvXmlSchemaPrivate {
+typedef struct {
 	char *xsd;
 	size_t xsd_size;
 	xmlSchemaParserCtxtPtr parser_ctxt;
 	xmlSchemaPtr schema;
 	xmlSchemaValidCtxtPtr valid_ctxt;
+} ArvXmlSchemaPrivate;
+
+struct _ArvXmlSchema
+{
+  GObject parent_instance;
+
+  ArvXmlSchemaPrivate *priv;
 };
 
-static GQuark
+struct _ArvXmlSchemaClass
+{
+  GObjectClass parent_class;
+};
+
+G_DEFINE_TYPE_WITH_CODE (ArvXmlSchema, arv_xml_schema, G_TYPE_OBJECT, G_ADD_PRIVATE (ArvXmlSchema))
+
+GQuark
 arv_xml_schema_error_quark (void)
 {
-	static GQuark q = 0;
-
-	if (q == 0) {
-		q = g_quark_from_static_string ("vmo-xml-schema-error-quark");
-	}
-
-	return q;
+	return g_quark_from_static_string ("arv-xml-schema-error-quark");
 }
 
-#define ARV_XML_SCHEMA_ERROR arv_xml_schema_error_quark ()
-
 typedef struct {
 	int line;
 	int column;
@@ -156,8 +162,6 @@ arv_xml_schema_new_from_path (const char *path)
 	return schema;
 }
 
-G_DEFINE_TYPE_WITH_CODE (ArvXmlSchema, arv_xml_schema, G_TYPE_OBJECT, G_ADD_PRIVATE (ArvXmlSchema))
-
 static void
 arv_xml_schema_init (ArvXmlSchema *self)
 {
